@@ -1,12 +1,14 @@
 package Text::Hatena::AutoLink::HatenaDiary;
 use strict;
 use base qw(Text::Hatena::AutoLink::Scheme);
+use Jcode;
 
 my $pattern_about = qr/\[?(d:id:([A-Za-z][a-zA-Z0-9_\-]{2,14}):(about|keywordlist))\]?/i;
 my $pattern_archive = qr/\[?(d:id:([A-Za-z][a-zA-Z0-9_\-]{2,14}):(archive)(?::(\d{6}))?)\]?/i;
 my $pattern_diary = qr/\[?(d:id:([A-Za-z][a-zA-Z0-9_\-]{2,14}))(\:(\d{8}))?(?:(\#|:)([a-zA-Z0-9_]+))?\]?/i;
+my $pattern_keyword = qr/\[d:keyword:(.+?)\]/i;
 
-__PACKAGE__->patterns([$pattern_about, $pattern_archive, $pattern_diary]);
+__PACKAGE__->patterns([$pattern_about, $pattern_archive, $pattern_diary, $pattern_keyword]);
 
 sub init {
     my $self = shift;
@@ -23,6 +25,8 @@ sub parse {
         return $self->_parse_archive($text);
     } elsif ($text =~ /$pattern_diary/) {
         return $self->_parse_diary($text);
+    } elsif ($text =~ /$pattern_keyword/) {
+        return $self->_parse_keyword($text);
     }
 }
 
@@ -64,4 +68,16 @@ sub _parse_archive {
                    $self->{a_target_string}, $content);
 }
 
+sub _parse_keyword {
+    my $self = shift;
+    my $text = shift or return;
+    $text =~ /$pattern_keyword/ or return;
+    my $word = $1;
+    my $enword = $self->html_encode(Jcode->new($word, 'utf8')->euc);
+    $enword =~ s/%2f/\//gi;
+    return sprintf('<a href="http://%s/keyword/%s"%s>d:keyword:%s</a>',
+                   $self->{domain}, $enword, $self->{a_target_string},
+                   $word);
+}
+
 1;
